unit DCB_W2;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, DatCombo;

type
  TForm2 = class(TForm)
    ButtonExit: TButton;
    RadioGroupShortDateFormat: TRadioGroup;
    CheckBoxDisplayWeekday: TCheckBox;
    RadioGroupDayScope: TRadioGroup;
    RadioGroupDefaultRelativeNow: TRadioGroup;
    ButtonCheck: TButton;
    CheckBoxOnExit: TCheckBox;
    ComboBox1: TComboBox;
    CheckBoxStyle: TCheckBox;
    procedure ButtonExitClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure RadioGroupShortDateFormatClick(Sender: TObject);
    procedure CheckBoxDisplayWeekdayClick(Sender: TObject);
    procedure RadioGroupDayScopeClick(Sender: TObject);
    procedure RadioGroupDefaultRelativeNowClick(Sender: TObject);
    procedure ButtonCheckClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure CheckBoxStyleClick(Sender: TObject);
  private
    { Private-Deklarationen }
    DateComboBox1: TDateComboBox;
    procedure DateComboBox1Exit(Sender: TObject);
  public
    { Public-Deklarationen }
  end;

var
  Form2: TForm2;

implementation
uses DCB_W1;
{$R *.DFM}

{**********************************************************************}
{                                                                      }
{**********************************************************************}

const

  { available ShortDateFormats }
  nFormat = 3;
  AFormat: array [0..nFormat] of string = ('??????????', 'mm-dd-yyyy',
    'dd.mm.yy', 'dd.mm.yyyy');
  ASeparator: array [0..nFormat] of char = ('?', '-', '.', '.');

  { selectable _DayScope }
  nScope = 3;
  AScope: array [0..nScope] of integer = (14, 7, 2, 0);

  { selectable _DefaultRelativeToday }
  nDefault = 3;
  ADefault: array [0..nDefault] of integer = (0, 1, -1, -28);
  ADefaultText: array [0..nDefault] of string = ('Today', 'Tomorrow',
    'Yesterday', '4 weeks ago');

{**********************************************************************}
{ - create component DateComboBox1 at run time                         }
{ - initialize radio groups etc.                                       }
{**********************************************************************}

procedure TForm2.FormCreate(Sender: TObject);

var i: integer;

begin

  { ComboBox1 has 2 purposes:
    1. Show the position of DateComboBox1 at design time
    2. Provide the right TabOrder for DateComboBox1
    At run time, it is hidden }
  ComboBox1.Visible := false;

  { create new component dynamically, so you can test is *BEFORE* installing }
  DateComboBox1 := TDateComboBox.Create (Self);
  with DateComboBox1 do begin
    Parent := Self;
    Top := 215;
    Left := 25;
    Height := 21;
    Width := 145;
    OnExit := DateComboBox1Exit;
    TabOrder := ComboBox1.TabOrder;
  end;


  { save current settings }
  AFormat [0] := ShortDateFormat;
  ASeparator [0] := DateSeparator;

  { initialize RadioGroup for selecting ShortDateFormat }
  with RadioGroupShortDateFormat.Items do begin
    Clear;
    Add (AFormat [0] + ' (current setting)');
    for i := 1 to nFormat do
      Add (AFormat [i]);
  end;
  RadioGroupShortDateFormat.ItemIndex := 0;

  { initialize RadioGroup for selecting _DayScope }
  with RadioGroupDayScope.Items do begin
    Clear;
    for i := 0 to nScope do
      Add (IntToStr (AScope [i]));
  end;
  RadioGroupDayScope.ItemIndex := 1;

  { initialize RadioGroup for selecting _DefaultRelativeNow }
  with RadioGroupDefaultRelativeNow.Items do begin
    Clear;
    for i := 0 to nDefault do
      Add (IntToStr (ADefault [i]) + '  (' + ADefaultText [i] + ')');
  end;
  RadioGroupDefaultRelativeNow.ItemIndex := 0;

end;

{**********************************************************************}
{ don't forget to free dynamically created component!                  }
{**********************************************************************}

procedure TForm2.FormDestroy(Sender: TObject);
begin
  DateComboBox1.Free;
end;

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TForm2.ButtonExitClick(Sender: TObject);
begin
  close;
end;

{**********************************************************************}
{ select setting of ShortDateFormat                                    }
{**********************************************************************}

procedure TForm2.RadioGroupShortDateFormatClick(Sender: TObject);
begin
  ShortDateFormat := AFormat [RadioGroupShortDateFormat.ItemIndex];
  DateSeparator   := ASeparator [RadioGroupShortDateFormat.ItemIndex];
  DateComboBox1.ComputeItems;
end;

{**********************************************************************}
{ select setting of _DisplayWeekday                                    }
{**********************************************************************}

procedure TForm2.CheckBoxDisplayWeekdayClick(Sender: TObject);
begin
  DateComboBox1._DisplayWeekday := CheckBoxDisplayWeekday.Checked;
  DateComboBox1.ComputeItems;
end;

{**********************************************************************}
{ decide if entering of a date is possible                             }
{**********************************************************************}

procedure TForm2.CheckBoxStyleClick(Sender: TObject);
var i: integer;
begin
  { save actual ItemIndex, so DateComboBox1 will not be empty }
  i := DateComboBox1.ItemIndex;
  if CheckBoxStyle.Checked then begin
    DateComboBox1.Style := csDropDownList;
    DateComboBox1.ComputeItems;
    DateComboBox1.Validate;
  end
  else
    DateComboBox1.Style := csDropDown;
end;

{**********************************************************************}
{ select setting of                                                    }
{**********************************************************************}

procedure TForm2.RadioGroupDayScopeClick(Sender: TObject);
begin
  DateComboBox1._DayScope := AScope [RadioGroupDayScope.ItemIndex];
  DateComboBox1.ComputeItems;
end;

{**********************************************************************}
{ select setting of _DefaultRelativeNow                                }
{**********************************************************************}

procedure TForm2.RadioGroupDefaultRelativeNowClick(Sender: TObject);
begin
  DateComboBox1._DefaultRelativeToday :=
    ADefault [RadioGroupDefaultRelativeNow.ItemIndex];
  DateComboBox1.ComputeItems;
end;

{**********************************************************************}
{ check the selected/entered date                                      }
{**********************************************************************}

procedure TForm2.ButtonCheckClick(Sender: TObject);
begin
  if DateComboBox1.Text = '' then
    ShowMessage ('No Date entered')
  else if not DateComboBox1.DateValid then begin
    ShowMessage ('Date not valid!');
    DateComboBox1.SetFocus;
  end
  else
    ShowMessage ('Date entered in TDateTime format:' + #13#10 +
      FloatToStr (DateComboBox1.Date) + #13#10 +
      'displayed in selected ShortDateFormat:' + #13#10 +
      DateToStr (DateComboBox1.Date))
end;

{**********************************************************************}
{ demonstrates how to define an event for TDateTime                    }
{**********************************************************************}

procedure TForm2.DateComboBox1Exit(Sender: TObject);

var Component: TComponent;

begin

  if CheckBoxOnExit.Checked then begin

    { don't check if focus goes on exit button }
    Component := FindComponent ('ButtonExit');
    if not TWinControl (Component).Focused and
      not DateComboBox1.DateValid
    then begin
      ShowMessage (Format ('"%s" is not a valid date!' + #13#10 +
        'This message appears, because' + #13#10 +
        '"immediately check for valid date"' + #13#10 +
        'is checked.', [DateComboBox1.Text]));
      DateComboBox1.SetFocus;
    end;

  end;

end;

end.
